@@ -18,15 +18,15 @@ logger = logging.getLogger(__name__)
 
 class Worker:
 
-    _blocking = False
-    _sleep_sec = 1.
-    _timeout_sec = 60.
+    _blocking = True
+    _sleep_sec = None
+    _timeout_sec = 600.
     _life_timeout_sec = None
     _started = False
     _started_timestamp = None
     _worker = None
     _current_task = None
-    _raise_exception = True
+    _raise_exception = False
 
     def check_module(self, module_name):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
@@ -112,11 +112,11 @@ class Worker:
             # print(f'{func_name}: now={datetime.datetime.now()}; task: {self._current_task}')
             task_dict = database.get_record_dict(self._current_task)
             if process_type is None:
-                timer = threading.Timer(self._timeout_sec, self.stop_woker, args=(func_name,))
-                timer.setDaemon(False)
-                timer.start()
+                # timer = threading.Timer(self._timeout_sec, self.stop_woker, args=(func_name,))
+                # timer.setDaemon(False)
+                # timer.start()
                 result_dict = self.worker(task_dict)
-                timer.cancel()
+                # timer.cancel()
                 database.update_worker_task(result_dict, self._current_task, self._worker)
             elif process_type in ['fork', 'thread', 'kthread']:
                 if process_type == 'fork':
@@ -155,14 +155,16 @@ class Worker:
         except Exception as e:
             exception = e
             error = f'Exception in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.format_exc()}'
-            database.set_worker_error(error, self._worker, self._current_task)
         finally:
             if timer:
                 timer.cancel()
-            if self._raise_exception and exception:
-                raise exception
-            else:
-                if isinstance(error, str):
+            if exception:
+                if self._raise_exception:
+                    database.set_worker_error(error, self._worker, self._current_task)
+                    raise exception
+                else:
+                    database.update_worker_task({'status': 'error', 'result': error}, self._current_task,
+                                                self._worker)
                     logger.error(error)
             if not self._blocking:
                 if self._life_timeout_sec is not None:
@@ -171,6 +173,9 @@ class Worker:
                     if time_delta_sec > self._life_timeout_sec:
                         logger.info(f'{func_name}; time_delta_sec({time_delta_sec})'
                                     f' > life_timeout_sec({self._life_timeout_sec}) => return...')
+                        self._worker.status = 'finished'
+                        self._worker.finished_time = datetime.datetime.now()
+                        database.session.commit()
                         return
                 threading.Timer(self._sleep_sec, self._do_task, args=(process_type,)).start()
 
@@ -186,7 +191,7 @@ class Worker:
             return
 
         process_type = None
-        loops_limit = None
+        loops_limit = 20
         worker_cfg = config.cfg.get('worker')
 
         if isinstance(worker_cfg, dict):
@@ -236,7 +241,11 @@ class Worker:
                         logger.info(f'{func_name}; time_delta_sec({time_delta_sec})'
                                     f' > life_timeout_sec({self._life_timeout_sec}) => break...')
                         break
-                time.sleep(self._sleep_sec)
+                if self._sleep_sec is not None:
+                    time.sleep(self._sleep_sec)
+            self._worker.status = 'finished'
+            self._worker.finished_time = datetime.datetime.now()
+            database.session.commit()
         else:
             self._do_task(process_type)
 
@@ -246,8 +255,8 @@ class Worker:
 
 if __name__ == '__main__':
     name = 'Worker'
-    ver = '1.0'
-    release_date = '2020-06-01 09:24'
+    ver = '1.2'
+    release_date = '2020-06-05 11:15'
     version = f'{name}. ver: {ver} ({release_date})'
     from pg_tasks_queue.Logging import init_logger
     init_logger()
